@@ -35,12 +35,8 @@ filter_trace_frequency_threshold <- function(eventlog,
 	colnames(output)[colnames(output) == "case_classifier"] <- case_id(eventlog)
 
 
-	output <- eventlog(output,
-					   activity_id = activity_id(eventlog),
-					   case_id = case_id(eventlog),
-					   timestamp =timestamp(eventlog),
-					   lifecycle_id = lifecycle_id(eventlog),
-					   activity_instance_id = activity_instance_id(eventlog))
+	output <- re_map(output, mapping(eventlog))
+
 
 	return(output)
 
