@@ -1,23 +1,13 @@
-#' @title Resource Specialisation Plot
-#'
-#' @description  Visualize resource specialisation data.
-#' @param x Data to plot
-#' @param ... Additional variables
-#' @return A ggplot object, which can be customized further, if deemed necessary.
-#' @method plot resource_specialisation
 
-#' @export
 
-plot.resource_specialisation <- function(x, ...) {
+plot_resource_specialisation <- function(x, ...) {
 
-	data <- x
-
-	mapping <- attr(data, "mapping")
-	level <- attr(data, "level")
-	units <- attr(data, "units")
+	mapping <- attr(x, "mapping")
+	level <- attr(x, "level")
+	units <- attr(x, "units")
 
 	if(level == "log") {
-		attr(data, "raw") %>%
+		attr(x, "raw") %>%
 			ggplot(aes("", freq)) +
 			geom_boxplot() +
 			theme_light() +
@@ -28,7 +18,7 @@ plot.resource_specialisation <- function(x, ...) {
 		stop("No plot available at this level")
 	}
 	else if(level == "activity") {
-		data %>%
+		x %>%
 			ggplot(aes_string(glue("reorder({mapping$activity_id}, relative)"), "absolute")) +
 			geom_col(aes(fill = absolute)) +
 			theme_light() +
@@ -37,7 +27,7 @@ plot.resource_specialisation <- function(x, ...) {
 			labs(x = "Activities",y = "Number of resources") -> p
 	}
 	else if(level == "resource") {
-		data %>%
+		x %>%
 			ggplot(aes_string(glue("reorder({mapping$resource_id}, absolute)"), "absolute")) +
 			geom_col(aes(fill = absolute)) +
 			scale_fill_continuous_tableau(name = "Number of activities executed per resource", palette = "Blue") +
@@ -45,5 +35,12 @@ plot.resource_specialisation <- function(x, ...) {
 			theme_light() +
 			labs(x = "Resources",y = "Number of activities") -> p
 	}
+
+
+	if(!is.null(attr(x, "groups"))) {
+		p <- p + facet_grid(as.formula(paste(c(paste(attr(x, "groups"), collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+	}
+
+
 	return(p)
 }
