@@ -1,38 +1,31 @@
-#' @title Trace Length Plot
-#'
-#' @description  Visualize trace length data.
-#' @param x Data to plot
-#' @param ... Additional variables
-#' @return A ggplot object, which can be customized further, if deemed necessary.
-#' @method plot trace_length
 
-#' @export
 
-plot.trace_length <- function(x, ...) {
-	data <- x
+plot_trace_length <- function(x, ...) {
 
-	mapping <- attr(data, "mapping")
-	level <- attr(data, "level")
+	mapping <- attr(x, "mapping")
+	level <- attr(x, "level")
 
 	if(level == "log") {
-		attr(data, "raw") %>%
+		attr(x, "raw") %>%
 			ggplot(aes("", trace_length)) +
 			geom_boxplot()+
 			labs(x = "", y = "Trace length") +
-			theme_light() -> p
+			theme_light() +
+			coord_flip() -> p
 	}
 	else if(level == "case") {
-		data %>%
+		x %>%
 			ggplot(aes_string(glue("reorder({mapping$case_id}, trace_length)"), "trace_length")) +
 			geom_col(aes(fill = trace_length)) +
 			scale_fill_continuous_tableau(palette = "Blue", name = "Trace length per case") +
 			theme_light() +
-			theme(axis.text.x = element_blank(), axis.ticks.x = element_blank()) +
+			coord_flip() +
+			theme(axis.text.y = element_blank(), axis.ticks.y = element_blank()) +
 			labs(x = "Cases", y = "Trace length") -> p
 
 	}
 	else if(level == "trace") {
-		data %>%
+		x %>%
 			ggplot(aes(absolute)) +
 			geom_histogram(bins = 20, color = "black", fill = "white") +
 			labs(x = "Trace length", y = "Number of traces") +
@@ -40,5 +33,10 @@ plot.trace_length <- function(x, ...) {
 
 	}
 
+	if(!is.null(attr(x, "groups"))) {
+		p <- p + facet_grid(as.formula(paste(c(paste(attr(x, "groups"), collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+	}
+
+
 	return(p)
 }
