@@ -1,20 +1,16 @@
 
 start_activities_activity <- function(eventlog) {
 
-	stop_eventlog(eventlog)
-
 	eventlog %>%
-		rename_("event_classifier" = activity_id(eventlog),
-				"timestamp_classifier" = timestamp(eventlog)) %>%
-		group_by_(case_id(eventlog)) %>%
-		arrange(timestamp_classifier) %>%
-		summarize(first_event = first(event_classifier)) %>%
+		group_by(!!as.symbol(case_id(eventlog))) %>%
+		arrange(!!as.symbol(timestamp(eventlog))) %>%
+		summarize(first_event = first(!!as.symbol(activity_id(eventlog)))) %>%
 		group_by(first_event) %>%
 		summarize(absolute = n()) %>%
 		ungroup() %>%
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
-			   cum_sum = cumsum(relative))-> r
+			   cum_sum = cumsum(relative)) -> r
 
 	colnames(r)[colnames(r) == "first_event"] <- activity_id(eventlog)
 	return(r)
